# radbm [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

[![PyPI](https://img.shields.io/pypi/v/radbm)](https://pypi.org/project/radbm/)
[![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/radbm)](https://libraries.io/pypi/radbm)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/radbm)](https://pypi.org/project/radbm/)

branch | docs | build | coverage
 --- | --- | --- | --- 
master | [![Documentation Status](https://readthedocs.org/projects/radbm/badge/?version=latest)](https://radbm.readthedocs.io/en/latest/?badge=latest) | [![Build Status](https://travis-ci.com/duchesneaumathieu/radbm.svg?branch=master)](https://travis-ci.com/duchesneaumathieu/radbm) | [![Coveralls github](https://img.shields.io/coveralls/github/duchesneaumathieu/radbm)](https://coveralls.io/github/duchesneaumathieu/radbm?branch=master) 
develop | [![Documentation Status](https://readthedocs.org/projects/radbm/badge/?version=develop)](https://radbm.readthedocs.io/en/latest/?badge=develop) | [![Build Status](https://travis-ci.com/duchesneaumathieu/radbm.svg?branch=develop)](https://travis-ci.com/duchesneaumathieu/radbm) | [![Coveralls github](https://img.shields.io/coveralls/github/duchesneaumathieu/radbm/develop)](https://coveralls.io/github/duchesneaumathieu/radbm?branch=develop) 

Rapid Access Database Benchmark
